@@ -8,6 +8,7 @@ use App::Netdisco::Util::Daemon;
 use Role::Tiny;
 use namespace::clean;
 
+use Time::HiRes 'sleep';
 use App::Netdisco::JobQueue qw/jq_defer jq_complete/;
 
 sub worker_begin { (shift)->{started} = time }
@@ -40,15 +41,8 @@ sub worker_body {
       };
 
       $self->close_job($job);
-
-      # restart worker once a day.
-      my $hour = [localtime()]->[2];
-      if ($wid) {
-          if ((time >= ($self->{started} + 86400) and $hour == ($wid % 24))
-               or (time > ($self->{started} + 172800))) {
-              $self->exit(0, "recycling worker $wid");
-          }
-      }
+      sleep( setting('workers')->{'min_runtime'} || 0 );
+      $self->exit(0); # recycle worker
   }
 }
 
